@@ -49,6 +49,7 @@ import           Data.ListLike.IO
 import           Data.ListLike.FoldableLL
 import           Data.Int
 import           Data.Monoid
+import           Data.Semigroup (Semigroup(..))
 import qualified Data.ByteString.Char8 as BS
 import qualified Data.ByteString.Lazy.Char8 as BSL
 import qualified System.IO as IO
@@ -63,6 +64,9 @@ import           Control.Arrow
 newtype CharString = CS { unCS :: BS.ByteString }
   deriving (Read, Show, Eq, Ord)
 
+instance Semigroup CharString where
+  (<>) = mappend
+
 instance Monoid CharString where
   mempty = CS mempty
   mappend l r = CS $ mappend (unCS l) (unCS r)
@@ -178,6 +182,9 @@ instance StringLike CharString where
 newtype CharStringLazy = CSL { unCSL :: BSL.ByteString }
   deriving (Read, Show, Eq, Ord)
 
+instance Semigroup CharStringLazy where
+  (<>) = mappend
+
 instance Monoid CharStringLazy where
   mempty = CSL mempty
   mappend l r = CSL $ mappend (unCSL l) (unCSL r)
